@@ -65,12 +65,6 @@ GlassSpellingWordsList::get_termfreq() const
     RETURN(freq);
 }
 
-Xapian::termcount
-GlassSpellingWordsList::get_collection_freq() const
-{
-    throw Xapian::InvalidOperationError("GlassSpellingWordsList::get_collection_freq() not meaningful");
-}
-
 TermList *
 GlassSpellingWordsList::next()
 {
