@@ -2,7 +2,7 @@
  * @brief tests snippets
  */
 /* Copyright 2012 Mihai Bivol
- * Copyright 2015,2016,2017,2019 Olly Betts
+ * Copyright 2015,2016,2017,2019,2020 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -73,8 +73,6 @@ DEFINE_TESTCASE(snippet1, backend) {
     for (auto i : testcases) {
 	TEST_STRINGS_EQUAL(mset.snippet(i.input, i.len), i.expect);
     }
-
-    return true;
 }
 
 /// Test snippets with stemming.
@@ -98,8 +96,6 @@ DEFINE_TESTCASE(snippetstem1, backend) {
     for (auto i : testcases) {
 	TEST_STRINGS_EQUAL(mset.snippet(i.input, i.len, stem), i.expect);
     }
-
-    return true;
 }
 
 /// Test snippets with phrases.
@@ -126,8 +122,6 @@ DEFINE_TESTCASE(snippetphrase1, backend) {
     for (auto i : testcases) {
 	TEST_STRINGS_EQUAL(mset.snippet(i.input, i.len, stem), i.expect);
     }
-
-    return true;
 }
 
 /// Index file to a DB with TermGenerator.
@@ -207,8 +201,6 @@ DEFINE_TESTCASE(snippetmisc1, generated) {
     // fewer Unicode characters in this sample than the previous one.
     TEST_STRINGS_EQUAL(mset.snippet(mset[4].get_document().get_data(), 64, stem),
 		       "...<b>much</b> o’brien do we have?  <b>Miles</b> O’Brien, that’s how <b>much</b>.");
-
-    return true;
 }
 
 /// Test snippet term diversity.
@@ -238,8 +230,6 @@ DEFINE_TESTCASE(snippet_termcover1, backend) {
 	Xapian::MSet mset = enquire.get_mset(0, 0);
 	TEST_STRINGS_EQUAL(mset.snippet(i.input, i.len, stem, flags), i.expect);
     }
-
-    return true;
 }
 
 /// Test snippet term diversity cases with BoolWeight.
@@ -269,8 +259,6 @@ DEFINE_TESTCASE(snippet_termcover2, backend) {
 	Xapian::MSet mset = enquire.get_mset(0, 0);
 	TEST_STRINGS_EQUAL(mset.snippet(i.input, i.len, stem, flags), i.expect);
     }
-
-    return true;
 }
 
 /// Test snippet EMPTY_WITHOUT_MATCH flag
@@ -307,14 +295,12 @@ DEFINE_TESTCASE(snippet_empty, backend) {
     flags |= Xapian::MSet::SNIPPET_EMPTY_WITHOUT_MATCH;
     TEST_STRINGS_EQUAL(mset.snippet(input, len, stem, flags),
 		       "A <b>rubbish</b> <b>example</b> text");
-
-    return true;
 }
 
 /// Check snippets include certain preceding punctuation.
 DEFINE_TESTCASE(snippet_start_nonspace, backend) {
     Xapian::Enquire enquire(get_database("apitest_simpledata"));
-    enquire.set_query(Xapian::Query("foo"));
+    enquire.set_query(Xapian::Query("foo") | Xapian::Query("10"));
 
     Xapian::MSet mset = enquire.get_mset(0, 0);
 
@@ -426,7 +412,50 @@ DEFINE_TESTCASE(snippet_start_nonspace, backend) {
     TEST_STRINGS_EQUAL(mset.snippet(input, 5, stem),
 		       "...<b>foo</b>!");
 
-    return true;
+    // Check trailing characters are included when useful.
+    input = "/opt/foo/bin/";
+    TEST_STRINGS_EQUAL(mset.snippet(input, strlen(input), stem),
+		       "/opt/<b>foo</b>/bin/");
+
+    input = "\"foo bar\"";
+    TEST_STRINGS_EQUAL(mset.snippet(input, strlen(input), stem),
+		       "\"<b>foo</b> bar\"");
+
+    input = "\\\\server\\share\\foo\\";
+    TEST_STRINGS_EQUAL(mset.snippet(input, strlen(input), stem),
+		       "\\\\server\\share\\<b>foo</b>\\");
+
+    input = "«foo»";
+    TEST_STRINGS_EQUAL(mset.snippet(input, strlen(input), stem),
+		       "«<b>foo</b>»");
+
+    input = "#include <foo>";
+    TEST_STRINGS_EQUAL(mset.snippet(input, strlen(input), stem),
+		       "#include &lt;<b>foo</b>&gt;");
+
+    input = "(foo)";
+    TEST_STRINGS_EQUAL(mset.snippet(input, strlen(input), stem),
+		       "(<b>foo</b>)");
+
+    input = "{foo}";
+    TEST_STRINGS_EQUAL(mset.snippet(input, strlen(input), stem),
+		       "{<b>foo</b>}");
+
+    input = "[foo]";
+    TEST_STRINGS_EQUAL(mset.snippet(input, strlen(input), stem),
+		       "[<b>foo</b>]");
+
+    input = "`foo`";
+    TEST_STRINGS_EQUAL(mset.snippet(input, strlen(input), stem),
+		       "`<b>foo</b>`");
+
+    input = "@foo@";
+    TEST_STRINGS_EQUAL(mset.snippet(input, strlen(input), stem),
+		       "@<b>foo</b>@");
+
+    input = "foo for 10¢";
+    TEST_STRINGS_EQUAL(mset.snippet(input, strlen(input), stem),
+		       "<b>foo</b> for <b>10</b>¢");
 }
 
 /// Test snippets with small and zero length.
@@ -454,8 +483,6 @@ DEFINE_TESTCASE(snippet_small_zerolength, backend) {
     for (auto i : testcases) {
 	TEST_STRINGS_EQUAL(mset.snippet(i.input, i.len), i.expect);
     }
-
-    return true;
 }
 
 /// Test CJK ngrams.
@@ -489,6 +516,16 @@ DEFINE_TESTCASE(snippet_cjkngrams, generated) {
 
     s = mset.snippet(input, len / 2, stem, flags, "<b>", "</b>", "...");
     TEST_STRINGS_EQUAL(s, "...<b>已</b><b>經</b>有香港地...");
+}
 
-    return true;
+DEFINE_TESTCASE(snippet_empty_mset, backend) {
+    Xapian::Enquire enquire(get_database("apitest_simpledata"));
+    enquire.set_query(Xapian::Query());
+    Xapian::MSet mset = enquire.get_mset(0, 0);
+    TEST_STRINGS_EQUAL(mset.snippet("foo", 3), "foo");
+}
+
+DEFINE_TESTCASE(snippet_empty_mset2, !backend) {
+    Xapian::MSet mset;
+    TEST_STRINGS_EQUAL(mset.snippet("foo", 3), "foo");
 }
